@@ -11,12 +11,14 @@ REQUIREMENTS_TAG = 'requirements'
 PREPROCESSORS_TAG = 'preprocessor'
 POSTPROCESSORS_TAG = 'postprocessor'
 FUNCTIONS_TAG = 'functions'
+CVAT_INFO_TAG = 'cvat-info'
 
 SUPPORTED_TAGS = [
     REQUIREMENTS_TAG,
     PREPROCESSORS_TAG,
     POSTPROCESSORS_TAG,
-    FUNCTIONS_TAG
+    FUNCTIONS_TAG,
+    CVAT_INFO_TAG
 ]
 
 class NotebookProcessor():
@@ -41,6 +43,7 @@ class NotebookProcessor():
         preprocessor_block = list()
         postprocessor_block = list()
         functions_block = list()
+        cvat_info_block = list()
 
         for c in self.notebook.cells:
             if c.cell_type != "code":
@@ -62,13 +65,17 @@ class NotebookProcessor():
             elif FUNCTIONS_TAG == tag:
                 functions_block.append(c.source)
                 continue
+            elif CVAT_INFO_TAG == tag:
+                cvat_info_block.append(c.source)
+                continue
             else:
                 continue
         return {
             REQUIREMENTS_TAG: requirements_block,
             PREPROCESSORS_TAG: preprocessor_block,
             POSTPROCESSORS_TAG: postprocessor_block,
-            FUNCTIONS_TAG: functions_block
+            FUNCTIONS_TAG: functions_block,
+            CVAT_INFO_TAG: cvat_info_block
         }
 
     def get_cell_transformer_tag(self, metadata):
