@@ -1,7 +1,7 @@
 import os
 import shutil
 import logging
-from modeldeploy_proxy_controller.processors.nbprocessor import NotebookProcessor, REQUIREMENTS_TAG, PREPROCESSORS_TAG, POSTPROCESSORS_TAG, FUNCTIONS_TAG
+from modeldeploy_proxy_controller.processors.nbprocessor import NotebookProcessor, REQUIREMENTS_TAG, PREPROCESSORS_TAG, POSTPROCESSORS_TAG, FUNCTIONS_TAG, CVAT_INFO_TAG
 from modeldeploy_proxy_controller.rpc.errors import RPCInternalError
 import requests
 
@@ -39,6 +39,14 @@ def parse_notebook(request, source_notebook_path):
         else:
             source = '{}'.format(blocks[POSTPROCESSORS_TAG][0])
 
+    if len(blocks[CVAT_INFO_TAG]) > 1:
+        raise RuntimeError("CVAT info tag must be at most 1!")
+    elif len(blocks[CVAT_INFO_TAG]):
+        if source:
+            source = '{}{}{}'.format(source, NEW_LINES, blocks[CVAT_INFO_TAG][0])
+        else:
+            source = '{}'.format(blocks[CVAT_INFO_TAG][0])
+
     if len(blocks[FUNCTIONS_TAG]):
         for function in blocks[FUNCTIONS_TAG]:
             if source:
