@@ -57,11 +57,34 @@ def reset(request, proxy_url, source_notebook_path):
     nb_file.write(text)
     nb_file.close()
 
-def probe(request, proxy_url):
-    request.log.debug("probe_proxy")
+def info(request):
+    request.log.debug("info")
+    cwd = os.getcwd()
+    proxy_url = ""
+    path = ""
+    PROXY_URL_NAME = ".proxy"
+    try:
+        for root, dirs, files in os.walk(cwd):
+            if PROXY_URL_NAME in files:
+                path = os.path.join(root, PROXY_URL_NAME)
+                proxy_url = open(path).readline().strip()
+                break
+    except Exception:
+        pass
 
+    UNAVAILABLE = "Unavailable"
+    info = {
+        "directory": cwd,
+        "proxy_url": proxy_url,
+        "proxy_status": UNAVAILABLE
+    }
     if proxy_url:
         revise_proxy_api_url(request, proxy_url)
 
-    response = requests.get(STATUS_URL)
-    request.log.debug(str(response))
+        try:
+            response = requests.get(STATUS_URL)
+            if response.status_code == 200:
+                info['proxy_status'] = response.json().get("status", UNAVAILABLE)
+        except requests.exceptions.RequestException as e:
+            request.log.warn(str(e))
+    return info
